exceptiontools.SpannerError
===========================

.. abjad-lineage:: abjad.tools.exceptiontools.SpannerError.SpannerError

.. autoclass:: abjad.tools.exceptiontools.SpannerError.SpannerError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.SpannerError.SpannerError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpannerError.SpannerError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpannerError.SpannerError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpannerError.SpannerError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpannerError.SpannerError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpannerError.SpannerError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpannerError.SpannerError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.SpannerError.SpannerError.__unicode__
   :noindex:
